pub trait EventSender: Send + Sync {
// Required method
fn send_event(&self, event: Event) -> Result<(), &'static str>;
}Expand description
Event sending capability
Objects that can send events to other objects or channels.
pub trait EventSender: Send + Sync {
// Required method
fn send_event(&self, event: Event) -> Result<(), &'static str>;
}Event sending capability
Objects that can send events to other objects or channels.